@@ -3,12 +3,10 @@ package GraphViz::No;
 use strict;
 use warnings;
 use GraphViz;
-use vars qw($VERSION @ISA);
 
-# This is incremented every time there is a change to the API
-$VERSION = '0.01';
+our @ISA = qw(GraphViz);
 
-@ISA = qw(GraphViz);
+our $VERSION = '2.24';
 
 =head1 NAME
 
@@ -58,8 +56,8 @@ Leon Brocard E<lt>F<acme@astray.com>E<gt>
 
 Copyright (C) 2000-1, Leon Brocard
 
-This module is free software; you can redistribute it or modify it
-under the same terms as Perl itself.
+This module is free software; you can redistribute it or modify it under the Perl License,
+a copy of which is available at L<http://dev.perl.org/licenses/>.
 
 =cut
 
